@@ -1,6 +1,6 @@
 import argparse
 import logging
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 
 import pandas
 
@@ -76,9 +76,10 @@ def main(args):
     TaskProgress(service, facade, args).main()
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "list_cumulative_labor_time"
     subcommand_help = "日ごとタスクフェーズごとの累積作業時間を出力する。"
     description = "日ごとタスクフェーズごとの累積作業時間をCSV形式で出力する。"
     parser = annofabcli.common.cli.add_parser(subparsers, subcommand_name, subcommand_help, description=description)
     parse_args(parser)
+    return parser
